==> middle-schema-0.1.0.tar.gz: middle-schema-0.1.0/docs/conf.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.coverage',
    'sphinx.ext.doctest',
    'sphinx.ext.extlinks',
    'sphinx.ext.ifconfig',
    'sphinx.ext.napoleon',
    'sphinx.ext.todo',
    'sphinx.ext.viewcode',
    'sphinx.ext.mathjax',
]
if os.getenv('SPELLCHECK'):
    extensions += 'sphinxcontrib.spelling',
    spelling_show_suggestions = True
    spelling_lang = 'en_US'

source_suffix = '.rst'
master_doc = 'index'
project = 'middle-schema'
year = '2018'
author = 'Richard Kuesters'
copyright = '{0}, {1}'.format(year, author)
version = release = '0.1.0'

pygments_style = 'default'
templates_path = ['.']
extlinks = {
    'issue': ('https://github.com/vltr/middle-schema/issues/%s', '#'),
    'pr': ('https://github.com/vltr/middle-schema/pull/%s', 'PR #'),
}
# on_rtd is whether we are on readthedocs.org
on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

if not on_rtd:  # only set the theme if we're building docs locally
    html_theme = 'sphinx_rtd_theme'

html_logo = "static/middle-schema-logo.svg"
html_use_smartypants = True
html_last_updated_fmt = '%b %d, %Y'
html_split_index = False
html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
}
html_short_title = '%s-%s' % (project, version)

html_theme_options = {
    "style_external_links": True,
    "logo_only": False,
}

napoleon_use_ivar = True
napoleon_use_rtype = False
napoleon_use_param = False

==> middle-schema-0.2.0.tar.gz: middle-schema-0.2.0/docs/conf.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.coverage',
    'sphinx.ext.doctest',
    'sphinx.ext.extlinks',
    'sphinx.ext.ifconfig',
    'sphinx.ext.napoleon',
    'sphinx.ext.todo',
    'sphinx.ext.viewcode',
    'sphinx.ext.mathjax',
]
if os.getenv('SPELLCHECK'):
    extensions += 'sphinxcontrib.spelling',
    spelling_show_suggestions = True
    spelling_lang = 'en_US'

source_suffix = '.rst'
master_doc = 'index'
project = 'middle-schema'
year = '2018'
author = 'Richard Kuesters'
copyright = '{0}, {1}'.format(year, author)
version = release = '0.2.0'

pygments_style = 'default'
templates_path = ['.']
extlinks = {
    'issue': ('https://github.com/vltr/middle-schema/issues/%s', '#'),
    'pr': ('https://github.com/vltr/middle-schema/pull/%s', 'PR #'),
}
# on_rtd is whether we are on readthedocs.org
on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

if not on_rtd:  # only set the theme if we're building docs locally
    html_theme = 'sphinx_rtd_theme'

html_logo = "static/middle-schema-logo.svg"
html_use_smartypants = True
html_last_updated_fmt = '%b %d, %Y'
html_split_index = False
html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
}
html_short_title = '%s-%s' % (project, version)

html_theme_options = {
    "style_external_links": False,
    "logo_only": False,
}

napoleon_use_ivar = True
napoleon_use_rtype = False
napoleon_use_param = False
